# Cryptography318
Cryptography318 is a package intended for students of the MATH318 class
at Oberlin College. This package includes functions for generating primes,
testing composite numbers, and solving DLP's. This package also includes functions
useful in linear algebra, including Matrix and LinearMap objects that have 
functionality including finding RREF, solving system of equations, 
finding eigenvalues/eigenvectors, change-of-basis, etc.

## Required Packages
* numpy
* sympy

## Install
```angular2html
$ pip install cryptography318
```

### License
This package is unlicensed and not intended for public use.